@@ -10,7 +10,7 @@ use warnings;
 
 # We must do this hackery because `package NAME VER` does not work with _ in VER
 #   https://github.com/Perl/perl5/issues/21499
-our $VERSION = '0.001_001';
+our $VERSION = '0.003_001';
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -49,6 +49,12 @@ consistent place to add new abilities, such as more APIs for inspection and
 alteration of internal structures, metaprogramming around the new C<'class'>
 feature, and other such uses.
 
+This module should be considered B<experimental>; no API stability guarantees
+are made at this time. Behaviour may be added, altered, or removed in later
+versions. Once a workable API shape has been found, it is hoped that this
+module will eventually become dual-life and shipped as part of Perl core, as
+the implementation for PPC 0022. See the link in the L</SEE ALSO> section.
+
 =cut
 
 =head1 FUNCTIONS
@@ -60,9 +66,36 @@ feature, and other such uses.
 Returns a metapackage reference representing the given package name, creating
 it if it did not previously exist.
 
+An alternative to C<< meta::package->get >> in a plain function style.
+
+=head2 get_this_package
+
+   $metapkg = meta::get_this_package;
+
+I<Since version 0.02.>
+
+Returns a metapackage reference representing the package of the code that
+called the function.
+
+Useful for performing meta-programming on the contents of a module during its
+C<BEGIN> or loading time. Equivalent to but more efficient than the following:
+
+   meta::get_package(__PACKAGE__)
+
 =cut
 
-=head1 METHODS ON METAPACKAGES
+=head1 METHODS ON C<meta::package>
+
+=head2 get
+
+   $metapkg = meta::package->get( $pkgname );
+
+I<Since version 0.003_001.>
+
+Returns a metapackage reference representing the given package name, creating
+it if it did not previously exist.
+
+An alternative to C<meta::get_package> in an object constructor style.
 
 =head2 name
 
@@ -158,12 +191,21 @@ Returns a regular Perl reference to the symbol being represented.
 
 =cut
 
-=head1 METHODS ON METAGLOBS
+=head1 METHODS ON C<meta::glob>
 
 =cut
 
 @meta::glob::ISA = qw( meta::symbol );
 
+=head2 get
+
+   $metaglob = meta::glob->get( $globname );
+
+I<Since version 0.003_001.>
+
+Returns a metaglob reference representing the given symbol from the symbol
+table from a fully-qualified name, if it exists. Throws an exception if not.
+
 =head2 name
 
    $name = $metaglob->basename;
@@ -226,6 +268,34 @@ Returns the prototype of the subroutine.
 
 =cut
 
+=head1 TODO
+
+=over 4
+
+=item
+
+Setting the subname or prototype of a subroutine, inspired by the
+C<Sub::Util> functions of the same.
+
+=item
+
+Some kind of access around the signature of a signatured sub.
+
+=item
+
+Access to the new parts of API introduced by Perl 5.38 to deal with classes,
+methods, fields.
+
+=back
+
+=cut
+
+=head1 SEE ALSO
+
+L<PPC 0022 "metaprogramming"|https://github.com/Perl/PPCs/blob/main/ppcs/ppc0022-metaprogramming.md>
+
+=cut
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
